#' Copper prices
#'
#' Yearly copper prices for 14 consecutive years (in constant 1997 dollars).
#'
#'
#' @format Time series data
#' @source Makridakis, Wheelwright and Hyndman (1998) \emph{Forecasting:
#' methods and applications}, John Wiley & Sons: New York. Chapter 9.
#' @keywords datasets
#' @examples
#' plot(copper2)
#'
"copper2"
